@@ -26,7 +26,7 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
  * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
@@ -84,11 +84,11 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
             };
         final String[] Cuba = new String[] {
                "kubansk normaltid",
-               "",
+               "CST",
                "kubansk sommartid",
-               "",
+               "CDT",
                "kubansk tid",
-               "",
+               "CT",
             };
         final String[] Fiji = new String[] {
                "fijiansk normaltid",
@@ -148,11 +148,11 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
             };
         final String[] China = new String[] {
                "kinesisk normaltid",
-               "",
+               "CST",
                "kinesisk sommartid",
-               "",
+               "CDT",
                "kinesisk tid",
-               "",
+               "CT",
             };
         final String[] Cocos = new String[] {
                "tidssone for Kokos\u00f8yane",
@@ -164,27 +164,27 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
             };
         final String[] Japan = new String[] {
                "japansk normaltid",
-               "",
+               "JST",
                "japansk sommartid",
-               "",
+               "JDT",
                "japansk tid",
-               "",
+               "JT",
             };
         final String[] Korea = new String[] {
                "koreansk normaltid",
-               "",
+               "KST",
                "koreansk sommartid",
-               "",
+               "KST",
                "koreansk tid",
-               "",
+               "KST",
             };
         final String[] Samoa = new String[] {
                "samoansk normaltid",
-               "",
+               "SST",
                "samoansk sommartid",
-               "",
+               "SST",
                "samoansk tid",
-               "",
+               "SST",
             };
         final String[] Tonga = new String[] {
                "tongansk normaltid",
@@ -196,11 +196,11 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
             };
         final String[] Alaska = new String[] {
                "alaskisk normaltid",
-               "",
+               "AKST",
                "alaskisk sommartid",
-               "",
+               "AKDT",
                "alaskisk tid",
-               "",
+               "AKT",
             };
         final String[] Amazon = new String[] {
                "normaltid for Amazonas",
@@ -228,27 +228,27 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
             };
         final String[] Israel = new String[] {
                "israelsk normaltid",
-               "",
+               "IST",
                "israelsk sommartid",
-               "",
+               "IDT",
                "israelsk tid",
-               "",
+               "IT",
             };
         final String[] Moscow = new String[] {
                "normaltid for Moskva",
-               "",
+               "MSK",
                "sommartid for Moskva",
-               "",
+               "MSK",
                "tidssone for Moskva",
-               "",
+               "MSK",
             };
         final String[] Taipei = new String[] {
                "normaltid for Taipei",
-               "",
+               "CST",
                "sommartid for Taipei",
-               "",
+               "CDT",
                "tidssone for Taipei",
-               "",
+               "CT",
             };
         final String[] Wallis = new String[] {
                "tidssone for Wallis- og Futuna\u00f8yane",
@@ -348,11 +348,11 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
             };
         final String[] Atlantic = new String[] {
                "normaltid for den nordamerikanske atlanterhavskysten",
-               "",
+               "AST",
                "sommartid for den nordamerikanske atlanterhavskysten",
-               "",
+               "ADT",
                "tidssone for den nordamerikanske atlanterhavskysten",
-               "",
+               "AT",
             };
         final String[] Brasilia = new String[] {
                "normaltid for Brasilia",
@@ -388,11 +388,11 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
             };
         final String[] Pakistan = new String[] {
                "pakistansk normaltid",
-               "",
+               "PKT",
                "pakistansk sommartid",
-               "",
+               "PKST",
                "pakistansk tid",
-               "",
+               "PKT",
             };
         final String[] Paraguay = new String[] {
                "paraguayansk normaltid",
@@ -428,11 +428,11 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
             };
         final String[] Hong_Kong = new String[] {
                "hongkongkinesisk normaltid",
-               "",
+               "HKT",
                "hongkongkinesisk sommartid",
-               "",
+               "HKST",
                "hongkongkinesisk tid",
-               "",
+               "HKT",
             };
         final String[] Lord_Howe = new String[] {
                "normaltid for Lord Howe-\u00f8ya",
@@ -460,11 +460,11 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
             };
         final String[] Volgograd = new String[] {
                "normaltid for Volgograd",
-               "",
+               "MSK",
                "sommartid for Volgograd",
-               "",
+               "MSK",
                "tidssone for Volgograd",
-               "",
+               "MSK",
             };
         final String[] Azerbaijan = new String[] {
                "aserbajdsjansk normaltid",
@@ -524,11 +524,11 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
             };
         final String[] New_Zealand = new String[] {
                "nyzealandsk normaltid",
-               "",
-               "nyzealandsk sumartid",
-               "",
+               "NZST",
+               "nyzealandsk sommartid",
+               "NZDT",
                "nyzealandsk tid",
-               "",
+               "NZT",
             };
         final String[] Novosibirsk = new String[] {
                "normaltid for Novosibirsk",
@@ -540,11 +540,11 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
             };
         final String[] Philippines = new String[] {
                "filippinsk normaltid",
-               "",
+               "PST",
                "filippinsk sommartid",
-               "",
+               "PDT",
                "filippinsk tid",
-               "",
+               "PT",
             };
         final String[] Vladivostok = new String[] {
                "normaltid for Vladivostok",
@@ -564,11 +564,11 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
             };
         final String[] Newfoundland = new String[] {
                "normaltid for Newfoundland",
-               "",
+               "NST",
                "sommartid for Newfoundland",
-               "",
+               "NDT",
                "tidssone for Newfoundland",
-               "",
+               "NT",
             };
         final String[] Turkmenistan = new String[] {
                "turkmensk normaltid",
@@ -596,19 +596,19 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
             };
         final String[] Africa_Eastern = new String[] {
                "austafrikansk tid",
+               "EAT",
                "",
+               "EAT",
                "",
-               "",
-               "",
-               "",
+               "EAT",
             };
         final String[] Africa_Western = new String[] {
                "vestafrikansk standardtid",
-               "",
+               "WAT",
                "vestafrikansk sommartid",
-               "",
+               "WAT",
                "vestafrikansk tid",
-               "",
+               "WAT",
             };
         final String[] DumontDUrville = new String[] {
                "tidssone for Dumont-d\u2019Urville",
@@ -620,59 +620,59 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
             };
         final String[] Europe_Central = new String[] {
                "sentraleuropeisk standardtid",
-               "",
+               "CET",
                "sentraleuropeisk sommartid",
-               "",
+               "CEST",
                "sentraleuropeisk tid",
-               "",
+               "CET",
             };
         final String[] Europe_Eastern = new String[] {
                "austeuropeisk standardtid",
-               "",
+               "EET",
                "austeuropeisk sommartid",
-               "",
+               "EEST",
                "austeuropeisk tid",
-               "",
+               "EET",
             };
         final String[] Europe_Western = new String[] {
                "vesteuropeisk standardtid",
-               "",
+               "WET",
                "vesteuropeisk sommartid",
-               "",
+               "WEST",
                "vesteuropeisk tid",
-               "",
+               "WET",
             };
         final String[] Mexico_Pacific = new String[] {
                "normaltid for den meksikanske stillehavskysten",
-               "",
+               "MST",
                "sommartid for den meksikanske stillehavskysten",
-               "",
+               "MDT",
                "tidssone for den meksikanske stillehavskysten",
-               "",
+               "MT",
             };
         final String[] America_Central = new String[] {
                "normaltid for sentrale Nord-Amerika",
-               "",
+               "CST",
                "sommartid for sentrale Nord-Amerika",
-               "",
+               "CDT",
                "tidssone for sentrale Nord-Amerika",
-               "",
+               "CT",
             };
         final String[] America_Eastern = new String[] {
                "normaltid for den nordamerikanske austkysten",
-               "",
-               "sommartid for den nordamerikansk austkysten",
-               "",
+               "EST",
+               "sommartid for den nordamerikanske austkysten",
+               "EDT",
                "tidssone for den nordamerikanske austkysten",
-               "",
+               "ET",
             };
         final String[] America_Pacific = new String[] {
                "normaltid for den nordamerikanske stillehavskysten",
-               "",
+               "PST",
                "sommartid for den nordamerikanske stillehavskysten",
-               "",
+               "PDT",
                "tidssone for den nordamerikanske stillehavskysten",
-               "",
+               "PT",
             };
         final String[] French_Southern = new String[] {
                "tidssone for Dei franske s\u00f8rterritoria",
@@ -692,11 +692,11 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
             };
         final String[] Hawaii_Aleutian = new String[] {
                "normaltid for Hawaii og Aleutene",
-               "",
+               "HAST",
                "sommartid for Hawaii og Aleutene",
-               "",
+               "HADT",
                "tidssone for Hawaii og Aleutene",
-               "",
+               "HAT",
             };
         final String[] Phoenix_Islands = new String[] {
                "tidssone for Phoenix\u00f8yane",
@@ -716,75 +716,43 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
             };
         final String[] America_Mountain = new String[] {
                "normaltid for Rocky Mountains (USA)",
-               "",
+               "MST",
                "sommartid for Rocky Mountains (USA)",
-               "",
+               "MDT",
                "tidssone for Rocky Mountains (USA)",
-               "",
-            };
-        final String[] Mexico_Northwest = new String[] {
-               "normaltid for nordvestlege Mexico",
-               "",
-               "sommartid for nordvestlege Mexico",
-               "",
-               "tidssone for nordvestlege Mexico",
-               "",
+               "MT",
             };
         final String[] Australia_Central = new String[] {
                "sentralaustralsk standardtid",
-               "",
+               "ACST",
                "sentralaustralsk sommartid",
-               "",
+               "ACDT",
                "sentralaustralsk tid",
-               "",
+               "ACT",
             };
         final String[] Australia_Eastern = new String[] {
                "austaustralsk standardtid",
-               "",
+               "AEST",
                "austaustralsk sommartid",
-               "",
+               "AEDT",
                "austaustralsk tid",
-               "",
+               "AET",
             };
         final String[] Australia_Western = new String[] {
                "vestaustralsk standardtid",
-               "",
+               "AWST",
                "vestaustralsk sommartid",
-               "",
+               "AWDT",
                "vestaustralsk tid",
-               "",
-            };
-        final String[] Greenland_Eastern = new String[] {
-               "austgr\u00f8nlandsk normaltid",
-               "",
-               "austgr\u00f8nlandsk sommartid",
-               "",
-               "austgr\u00f8nlandsk tid",
-               "",
-            };
-        final String[] Greenland_Western = new String[] {
-               "vestgr\u00f8nlandsk normaltid",
-               "",
-               "vestgr\u00f8nlandsk sommartid",
-               "",
-               "vestgr\u00f8nlandsk tid",
-               "",
+               "AWT",
             };
         final String[] Indonesia_Eastern = new String[] {
                "austindonesisk tid",
+               "WIT",
                "",
+               "WIT",
                "",
-               "",
-               "",
-               "",
-            };
-        final String[] Kazakhstan_Eastern = new String[] {
-               "austkasakhstansk tid",
-               "",
-               "",
-               "",
-               "",
-               "",
+               "WIT",
             };
         final String[] Australia_CentralWestern = new String[] {
                "vest-sentralaustralsk standardtid",
@@ -812,42 +780,104 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
             { "Europe/Bucharest", Europe_Eastern },
             { "Asia/Shanghai", China },
             { "UTC", EMPTY_ZONE },
+            { "GB",
+                new String[] {
+                    "",
+                    "GMT",
+                    "britisk sommartid",
+                    "BST",
+                    "",
+                    "GMT",
+                }
+            },
+            { "NZ", New_Zealand },
             { "ACT", Australia_Central },
             { "AET", Australia_Eastern },
+            { "AGT", Argentina },
             { "ART", Europe_Eastern },
             { "AST", Alaska },
             { "BET", Brasilia },
             { "BST", Bangladesh },
+            { "CET", Europe_Central },
             { "CNT", Newfoundland },
             { "CST", America_Central },
             { "CTT", China },
             { "EAT", Africa_Eastern },
             { "ECT", Europe_Central },
+            { "EET", Europe_Eastern },
+            { "EST", America_Eastern },
+            { "HST", Hawaii_Aleutian },
+            { "IET", America_Eastern },
             { "JST", Japan },
+            { "MET", Europe_Central },
             { "MIT", Apia },
+            { "MST", America_Mountain },
             { "NET", Armenia },
             { "NST", New_Zealand },
             { "PLT", Pakistan },
             { "PNT", America_Mountain },
+            { "PRC", China },
             { "PRT", Atlantic },
             { "PST", America_Pacific },
+            { "ROK", Korea },
+            { "WET", Europe_Western },
+            { "Cuba", Cuba },
+            { "Eire",
+                new String[] {
+                    "",
+                    "GMT",
+                    "irsk sommartid",
+                    "IST",
+                    "",
+                    "GMT",
+                }
+            },
+            { "Iran", Iran },
+            { "W-SU", Moscow },
+            { "Egypt", Europe_Eastern },
+            { "Japan", Japan },
+            { "Libya", Europe_Eastern },
+            { "Israel", Israel },
+            { "Navajo", America_Mountain },
+            { "Poland", Europe_Central },
             { "CST6CDT", America_Central },
             { "EST5EDT", America_Eastern },
+            { "GB-Eire",
+                new String[] {
+                    "",
+                    "GMT",
+                    "britisk sommartid",
+                    "BST",
+                    "",
+                    "GMT",
+                }
+            },
+            { "Jamaica", America_Eastern },
             { "MST7MDT", America_Mountain },
+            { "NZ-CHAT", Chatham },
             { "PST8PDT", America_Pacific },
+            { "Hongkong", Hong_Kong },
+            { "Portugal", Europe_Western },
+            { "US/Samoa", Samoa },
             { "Asia/Aden", Arabian },
             { "Asia/Baku", Azerbaijan },
             { "Asia/Dili", East_Timor },
             { "Asia/Gaza", Europe_Eastern },
             { "Asia/Hovd", Hovd },
             { "Asia/Omsk", Omsk },
-            { "Asia/Amman", Europe_Eastern },
+            { "US/Alaska", Alaska },
+            { "US/Hawaii", Hawaii_Aleutian },
             { "Asia/Chita", Yakutsk },
+            { "Asia/Dacca", Bangladesh },
             { "Asia/Dhaka", Bangladesh },
+            { "Asia/Macao", China },
             { "Asia/Macau", China },
             { "Asia/Qatar", Arabian },
             { "Asia/Seoul", Korea },
-            { "Asia/Almaty", Kazakhstan_Eastern },
+            { "US/Arizona", America_Mountain },
+            { "US/Central", America_Central },
+            { "US/Eastern", America_Eastern },
+            { "US/Pacific", America_Pacific },
             { "Asia/Beirut", Europe_Eastern },
             { "Asia/Harbin", China },
             { "Asia/Hebron", Europe_Eastern },
@@ -856,16 +886,24 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
             { "Asia/Riyadh", Arabian },
             { "Asia/Taipei", Taipei },
             { "Asia/Tehran", Iran },
+            { "Asia/Yangon", Cocos },
+            { "Brazil/East", Brasilia },
+            { "Brazil/West", Amazon },
             { "Europe/Kiev", Europe_Eastern },
+            { "Europe/Kyiv", Europe_Eastern },
             { "Europe/Oslo", Europe_Central },
             { "Europe/Riga", Europe_Eastern },
             { "Europe/Rome", Europe_Central },
             { "Pacific/Yap", Truk },
+            { "US/Aleutian", Hawaii_Aleutian },
+            { "US/Michigan", America_Eastern },
+            { "US/Mountain", America_Mountain },
             { "Africa/Cairo", Europe_Eastern },
             { "Africa/Ceuta", Europe_Central },
             { "Africa/Lagos", Africa_Western },
             { "Africa/Tunis", Europe_Central },
             { "America/Adak", Hawaii_Aleutian },
+            { "America/Atka", Hawaii_Aleutian },
             { "America/Lima", Peru },
             { "America/Nome", Alaska },
             { "Asia/Baghdad", Arabian },
@@ -889,6 +927,7 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
             { "SystemV/CST6", America_Central },
             { "SystemV/EST5", America_Eastern },
             { "SystemV/MST7", America_Mountain },
+            { "Africa/Asmara", Africa_Eastern },
             { "Africa/Asmera", Africa_Eastern },
             { "Africa/Bangui", Africa_Western },
             { "Africa/Douala", Africa_Western },
@@ -902,34 +941,46 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
             { "America/Jujuy", Argentina },
             { "America/Thule", Atlantic },
             { "Asia/Ashgabat", Turkmenistan },
-            { "Asia/Damascus", Europe_Eastern },
             { "Asia/Jayapura", Indonesia_Eastern },
             { "Asia/Khandyga", Yakutsk },
-            { "Asia/Qostanay", Kazakhstan_Eastern },
             { "Asia/Sakhalin", Sakhalin },
             { "Asia/Tashkent", Uzbekistan },
+            { "Asia/Tel_Aviv", Israel },
             { "Asia/Ust-Nera", Vladivostok },
+            { "Australia/ACT", Australia_Eastern },
+            { "Australia/LHI", Lord_Howe },
+            { "Australia/NSW", Australia_Eastern },
             { "Europe/Athens", Europe_Eastern },
             { "Europe/Berlin", Europe_Central },
             { "Europe/Dublin",
                 new String[] {
                     "",
-                    "",
+                    "GMT",
                     "irsk sommartid",
+                    "IST",
                     "",
+                    "GMT",
+                }
+            },
+            { "Europe/Jersey",
+                new String[] {
                     "",
+                    "GMT",
+                    "britisk sommartid",
+                    "BST",
                     "",
+                    "GMT",
                 }
             },
             { "Europe/Lisbon", Europe_Western },
             { "Europe/London",
                 new String[] {
                     "",
-                    "",
+                    "GMT",
                     "britisk sommartid",
+                    "BST",
                     "",
-                    "",
-                    "",
+                    "GMT",
                 }
             },
             { "Europe/Madrid", Europe_Central },
@@ -944,6 +995,7 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
             { "Europe/Zurich", Europe_Central },
             { "Indian/Comoro", Africa_Eastern },
             { "Pacific/Efate", Vanuatu },
+            { "Pacific/Samoa", Samoa },
             { "SystemV/HST10", Hawaii_Aleutian },
             { "Africa/Algiers", Europe_Central },
             { "Africa/Kampala", Africa_Eastern },
@@ -954,7 +1006,6 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
             { "America/Cancun", America_Eastern },
             { "America/Cayman", America_Eastern },
             { "America/Cuiaba", Amazon },
-            { "America/Dawson", America_Mountain },
             { "America/Havana", Cuba },
             { "America/Inuvik", America_Mountain },
             { "America/Juneau", Alaska },
@@ -965,30 +1016,42 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
             { "America/Panama", America_Eastern },
             { "America/Recife", Brasilia },
             { "America/Regina", America_Central },
+            { "America/Virgin", Atlantic },
+            { "Asia/Ashkhabad", Turkmenistan },
             { "Asia/Chongqing", China },
+            { "Asia/Chungking", China },
             { "Asia/Hong_Kong", Hong_Kong },
             { "Asia/Pyongyang", Korea },
             { "Asia/Samarkand", Uzbekistan },
+            { "Atlantic/Faroe", Europe_Western },
+            { "Australia/West", Australia_Western },
+            { "Canada/Central", America_Central },
+            { "Canada/Eastern", America_Eastern },
+            { "Canada/Pacific", America_Pacific },
             { "Europe/Andorra", Europe_Central },
             { "Europe/Belfast",
                 new String[] {
                     "",
-                    "",
+                    "GMT",
                     "britisk sommartid",
+                    "BST",
                     "",
-                    "",
-                    "",
+                    "GMT",
                 }
             },
+            { "Europe/Nicosia", Europe_Eastern },
             { "Europe/Tallinn", Europe_Eastern },
             { "Europe/Vatican", Europe_Central },
             { "Europe/Vilnius", Europe_Eastern },
             { "Indian/Mayotte", Africa_Eastern },
+            { "Mexico/BajaSur", Mexico_Pacific },
+            { "Mexico/General", America_Central },
             { "Pacific/Easter", Easter },
+            { "Pacific/Kanton", Phoenix_Islands },
             { "Pacific/Midway", Samoa },
             { "Pacific/Noumea", New_Caledonia },
             { "Pacific/Tarawa", Gilbert_Islands },
-            { "Pacific/Wallis", Wallis },
+            { "Pacific/Wallis", Gilbert_Islands },
             { "Africa/Djibouti", Africa_Eastern },
             { "Africa/Kinshasa", Africa_Western },
             { "Africa/Ndjamena", Africa_Western },
@@ -997,35 +1060,52 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
             { "America/Creston", America_Mountain },
             { "America/Curacao", Atlantic },
             { "America/Detroit", America_Eastern },
-            { "America/Godthab", Greenland_Western },
             { "America/Grenada", Atlantic },
             { "America/Iqaluit", America_Eastern },
             { "America/Jamaica", America_Eastern },
+            { "America/Knox_IN", America_Central },
             { "America/Managua", America_Central },
             { "America/Marigot", Atlantic },
             { "America/Mendoza", Argentina },
             { "America/Moncton", Atlantic },
             { "America/Nipigon", America_Eastern },
             { "America/Noronha", Noronha },
-            { "America/Ojinaga", America_Mountain },
+            { "America/Ojinaga", America_Central },
             { "America/Tijuana", America_Pacific },
             { "America/Toronto", America_Eastern },
             { "America/Tortola", Atlantic },
             { "America/Yakutat", Alaska },
             { "Asia/Choibalsan", Mongolia },
+            { "Asia/Ulan_Bator", Mongolia },
             { "Atlantic/Azores", Azores },
             { "Atlantic/Canary", Europe_Western },
             { "Atlantic/Faeroe", Europe_Western },
             { "Australia/Eucla", Australia_CentralWestern },
+            { "Australia/North", Australia_Central },
             { "Australia/Perth", Australia_Western },
+            { "Australia/South", Australia_Central },
+            { "Canada/Atlantic", Atlantic },
+            { "Canada/Mountain", America_Mountain },
             { "Europe/Belgrade", Europe_Central },
             { "Europe/Brussels", Europe_Central },
             { "Europe/Budapest", Europe_Central },
             { "Europe/Busingen", Europe_Central },
             { "Europe/Chisinau", Europe_Eastern },
+            { "Europe/Guernsey",
+                new String[] {
+                    "",
+                    "GMT",
+                    "britisk sommartid",
+                    "BST",
+                    "",
+                    "GMT",
+                }
+            },
             { "Europe/Helsinki", Europe_Eastern },
             { "Europe/Sarajevo", Europe_Central },
+            { "Europe/Tiraspol", Europe_Eastern },
             { "Europe/Uzhgorod", Europe_Eastern },
+            { "Indian/Maldives", French_Southern },
             { "Pacific/Chatham", Chatham },
             { "Pacific/Norfolk", Norfolk },
             { "SystemV/AST4ADT", Atlantic },
@@ -1037,9 +1117,11 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
             { "Africa/Mogadishu", Africa_Eastern },
             { "America/Anguilla", Atlantic },
             { "America/Asuncion", Paraguay },
+            { "America/Atikokan", America_Eastern },
             { "America/Barbados", Atlantic },
             { "America/Dominica", Atlantic },
             { "America/Edmonton", America_Mountain },
+            { "America/Ensenada", America_Pacific },
             { "America/Mazatlan", Mexico_Pacific },
             { "America/Miquelon", Pierre_Miquelon },
             { "America/Montreal", America_Eastern },
@@ -1050,6 +1132,7 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
             { "America/St_Kitts", Atlantic },
             { "America/St_Lucia", Atlantic },
             { "America/Winnipeg", America_Central },
+            { "Antarctica/Casey", Australia_Western },
             { "Asia/Krasnoyarsk", Krasnoyarsk },
             { "Asia/Novosibirsk", Novosibirsk },
             { "Asia/Ulaanbaatar", Mongolia },
@@ -1061,6 +1144,7 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
             { "Australia/Darwin", Australia_Central },
             { "Australia/Hobart", Australia_Eastern },
             { "Australia/Sydney", Australia_Eastern },
+            { "Brazil/DeNoronha", Noronha },
             { "Europe/Amsterdam", Europe_Central },
             { "Europe/Gibraltar", Europe_Central },
             { "Europe/Ljubljana", Europe_Central },
@@ -1070,6 +1154,7 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
             { "Europe/Volgograd", Volgograd },
             { "Indian/Kerguelen", French_Southern },
             { "Indian/Mauritius", Mauritius },
+            { "Mexico/BajaNorte", America_Pacific },
             { "Pacific/Auckland", New_Zealand },
             { "Pacific/Johnston", Hawaii_Aleutian },
             { "Africa/Libreville", Africa_Western },
@@ -1077,7 +1162,7 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
             { "America/Araguaina", Brasilia },
             { "America/Boa_Vista", Amazon },
             { "America/Catamarca", Argentina },
-            { "America/Chihuahua", Mexico_Pacific },
+            { "America/Chihuahua", America_Central },
             { "America/Fortaleza", Brasilia },
             { "America/Glace_Bay", Atlantic },
             { "America/Goose_Bay", Atlantic },
@@ -1089,6 +1174,7 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
             { "America/St_Thomas", Atlantic },
             { "America/Vancouver", America_Pacific },
             { "Asia/Novokuznetsk", Krasnoyarsk },
+            { "Chile/Continental", Chile },
             { "Europe/Bratislava", Europe_Central },
             { "Europe/Copenhagen", Europe_Central },
             { "Europe/Luxembourg", Europe_Central },
@@ -1101,6 +1187,7 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
             { "Pacific/Pago_Pago", Samoa },
             { "Pacific/Rarotonga", Cook },
             { "Pacific/Tongatapu", Tonga },
+            { "US/Indiana-Starke", America_Central },
             { "Africa/Addis_Ababa", Africa_Eastern },
             { "Africa/Brazzaville", Africa_Western },
             { "America/Costa_Rica", America_Central },
@@ -1114,13 +1201,26 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
             { "America/Montevideo", Uruguay },
             { "America/Montserrat", Atlantic },
             { "America/St_Vincent", Atlantic },
-            { "America/Whitehorse", America_Mountain },
             { "Antarctica/McMurdo", New_Zealand },
             { "Asia/Yekaterinburg", Yekaterinburg },
             { "Atlantic/Jan_Mayen", Europe_Central },
             { "Australia/Adelaide", Australia_Central },
             { "Australia/Brisbane", Australia_Eastern },
+            { "Australia/Canberra", Australia_Eastern },
             { "Australia/Lindeman", Australia_Eastern },
+            { "Australia/Tasmania", Australia_Eastern },
+            { "Australia/Victoria", Australia_Eastern },
+            { "Chile/EasterIsland", Easter },
+            { "Europe/Isle_of_Man",
+                new String[] {
+                    "",
+                    "GMT",
+                    "britisk sommartid",
+                    "BST",
+                    "",
+                    "GMT",
+                }
+            },
             { "Europe/Kaliningrad", Europe_Eastern },
             { "Pacific/Kiritimati", Line_Islands },
             { "America/El_Salvador", America_Central },
@@ -1137,6 +1237,8 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
             { "Atlantic/Cape_Verde", Cape_Verde },
             { "Australia/Lord_Howe", Lord_Howe },
             { "Australia/Melbourne", Australia_Eastern },
+            { "Canada/Newfoundland", Newfoundland },
+            { "Canada/Saskatchewan", America_Central },
             { "Indian/Antananarivo", Africa_Eastern },
             { "Africa/Dar_es_Salaam", Africa_Eastern },
             { "America/Blanc-Sablon", Atlantic },
@@ -1145,10 +1247,13 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
             { "America/Dawson_Creek", America_Mountain },
             { "America/Indiana/Knox", America_Central },
             { "America/Rankin_Inlet", America_Central },
-            { "America/Santa_Isabel", Mexico_Northwest },
-            { "America/Scoresbysund", Greenland_Eastern },
+            { "America/Santa_Isabel", America_Pacific },
             { "Antarctica/Macquarie", Australia_Eastern },
+            { "Australia/Queensland", Australia_Eastern },
+            { "Australia/Yancowinna", Australia_Central },
+            { "Pacific/Port_Moresby", DumontDUrville },
             { "America/Cambridge_Bay", America_Mountain },
+            { "America/Ciudad_Juarez", America_Mountain },
             { "America/Coral_Harbour", America_Eastern },
             { "America/Indiana/Vevay", America_Eastern },
             { "America/Lower_Princes", Atlantic },
@@ -1160,9 +1265,12 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
             { "Australia/Broken_Hill", Australia_Central },
             { "America/Bahia_Banderas", America_Central },
             { "America/Port-au-Prince", America_Eastern },
+            { "America/Argentina/Jujuy", Argentina },
             { "America/Argentina/Salta", Argentina },
             { "America/Indiana/Marengo", America_Eastern },
             { "America/Indiana/Winamac", America_Eastern },
+            { "America/Argentina/Cordoba", Argentina },
+            { "America/Argentina/Mendoza", Argentina },
             { "America/Argentina/Tucuman", Argentina },
             { "America/Argentina/Ushuaia", Argentina },
             { "America/Indiana/Tell_City", America_Central },
@@ -1173,21 +1281,24 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
             { "America/Argentina/San_Juan", Argentina },
             { "America/Argentina/San_Luis", Argentina },
             { "America/Indiana/Petersburg", America_Eastern },
+            { "America/Argentina/Catamarca", Argentina },
+            { "America/Kentucky/Louisville", America_Eastern },
             { "America/Kentucky/Monticello", America_Eastern },
             { "America/North_Dakota/Beulah", America_Central },
             { "America/North_Dakota/Center", America_Central },
             { "timezone.excity.Asia/Aqtobe", "Aktobe" },
             { "timezone.excity.Etc/Unknown", "ukjend by" },
+            { "America/Indiana/Indianapolis", America_Eastern },
             { "timezone.excity.Asia/Rangoon", "Yang\u00f4n" },
             { "timezone.excity.Indian/Cocos", "Kokos\u00f8yane" },
             { "timezone.excity.Asia/Ashgabat", "Asjgabat" },
             { "timezone.excity.Indian/Comoro", "Komorane" },
+            { "America/Argentina/Buenos_Aires", Argentina },
             { "America/Argentina/Rio_Gallegos", Argentina },
             { "America/North_Dakota/New_Salem", America_Central },
             { "timezone.excity.America/Cayman", "Cayman\u00f8yane" },
             { "timezone.excity.America/Cuiaba", "Cuiaba" },
             { "timezone.excity.America/Merida", "Merida" },
-            { "timezone.excity.Asia/Choibalsan", "Tsjojbalsan" },
             { "timezone.excity.Atlantic/Azores", "Asorane" },
             { "timezone.excity.Atlantic/Canary", "Kanari\u00f8yane" },
             { "timezone.excity.Atlantic/Faeroe", "F\u00e6r\u00f8yane" },
